package de.scandio.tree;

import java.util.Collection;
import java.util.HashSet;
import java.util.TreeSet;

import org.springframework.roo.addon.javabean.RooJavaBean;

import flexjson.JSONSerializer;

@RooJavaBean
public class JsonNode {
	
	private Long id;
	
	private String name;
	
	private boolean hasChildren;
	
	private Collection<JsonNodeRef> childrenRef = new HashSet<JsonNodeRef>();

    public JsonNode(Node node) {
    	this.id = node.getId();
    	this.name = node.getName();
    	this.hasChildren = !node.getChildren().isEmpty();
    	for(Node child: node.getChildren()) {
			this.childrenRef.add(new JsonNodeRef(child));
		}
    }
    
    public String toJson() {
    	return new JSONSerializer().exclude("*.class").include("childrenRef").serialize(this);
    }
    
    public static String toJsonArray(Collection<JsonNode> collection) {
    	return new JSONSerializer().exclude("*.class").include("childrenRef").serialize(collection);
    }
    
    public static Collection<JsonNode> findJsonNodeRoot() {
    	Collection<JsonNode> children = new TreeSet<JsonNode>();
    	for(Node child: Node.findRootNodes().getResultList()) {
    		children.add(new JsonNode(child));
    	}
    	return children;
    }
    
    public static JsonNode findJsonNode(Long id) {
		Node node = Node.findNode(id);
		return new JsonNode(node);
	}
}
